# appscii

## Application in ASCII for Python

## Installation

The appscii library is easy to install using pip:
```
pip install appscii
```

## Usage

Coming soon.

## Alternatives

- Python Prompt Toolkit
- Textualize
- DeskApp

## Author

Created by Shawn A. Wilson [lannocc@yahoo.com] aka LANNOCC.

